==> nextcloud-app-calendar-1%3A2.3.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/lv.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s dalijās ar kalendāru »%s«",
    "Hello," : "Sveicināti,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Mēs jūs vēlējāmies informēt, ka %s publicēja kalendāru »%s«.",
    "Open »%s«" : "Atvērt »%s«",
    "Cheers!" : "Priekā!",
    "Calendar" : "Kalendārs",
    "A Calendar app for Nextcloud" : "Kalendāra lietotne priekš Nextcloud",
    "Today" : "Šodien",
    "Day" : "Diena",
    "Week" : "Nedēļa",
    "Month" : "Mēnesis",
    "List" : "Saraksts",
    "Download" : "Lejupielādēt",
    "Delete" : "Dzēst",
    "Share link" : "Koplietot saiti",
    "Share with users or groups" : "Koplietot ar lietotājiem vai grupām",
    "No users or groups" : "Nav lietotāji vai grupas",
    "can edit" : "var rediģēt",
    "New calendar" : "Jauns kalendārs",
    "Filename" : "Datnes nosaukums",
    "Cancel" : "Atcelt",
    "Automatic" : "Automātisks",
    "Actions" : "Darbības",
    "Show week numbers" : "Rādīt nedēļu numurus",
    "Settings & import" : "Iestatījumi un imports",
    "Notification" : "Paziņojums",
    "Email" : "E-pasts",
    "Busy" : "Aizņemts",
    "Unknown" : "Nezināms",
    "All day" : "Visas dienas",
    "never" : "nekad",
    "after" : "pēc",
    "Repeat" : "Atkārtot",
    "Monday" : "Pirmdiena",
    "Summary" : "Kopsavilkums",
    "More" : "Vairāk",
    "Save" : "Saglabāt",
    "Update" : "Atjaunināt",
    "Personal" : "Personīgs",
    "Details" : "Detaļas",
    "Attendees" : "Apmeklētāji",
    "Reminders" : "Atgādinājumi",
    "Close" : "Aizvērt",
    "Anniversary" : "Gadadiena",
    "Week {number} of {year}" : "{number} nedēļa no {year}",
    "Daily" : "Katru dienu",
    "Weekly" : "Katru nedēļu",
    "When shared show full event" : "Ja koplietots, tad rādīt pilnu notikumu",
    "When shared show only busy" : "Ja koplietots, tad rādīt tikai aizņemts",
    "When shared hide this event" : "Ja koplietots, tad paslēpt notikumu",
    "Location" : "Vieta",
    "Description" : "Apraksts",
    "Status" : "Status",
    "Confirmed" : "Apstiprināts",
    "Tentative" : "Mēģinājums",
    "Categories" : "Kategorijas",
    "Presentation" : "Prezentācija",
    "Mail" : "E-pasts",
    "Global" : "Globāls"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-app-calendar-1%3A2.4.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/lv.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s dalijās ar kalendāru »%s«",
    "Hello," : "Sveicināti,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Mēs jūs vēlējāmies informēt, ka %s publicēja kalendāru »%s«.",
    "Open »%s«" : "Atvērt »%s«",
    "Cheers!" : "Priekā!",
    "Calendar" : "Kalendārs",
    "A Calendar app for Nextcloud" : "Kalendāra lietotne priekš Nextcloud",
    "+ New event" : "+ Jauns notikums",
    "Today" : "Šodien",
    "Day" : "Diena",
    "Week" : "Nedēļa",
    "Month" : "Mēnesis",
    "List" : "Saraksts",
    "Download" : "Lejupielādēt",
    "Delete" : "Dzēst",
    "Share link" : "Koplietot saiti",
    "Share with users or groups" : "Koplietot ar lietotājiem vai grupām",
    "No users or groups" : "Nav lietotāji vai grupas",
    "can edit" : "var rediģēt",
    "+ New calendar" : "+ Jauns kalendārs",
    "New calendar" : "Jauns kalendārs",
    "New calendar with task list" : "Jauns kalendārs ar uzdevumu sarakstu",
    "Filename" : "Datnes nosaukums",
    "Cancel" : "Atcelt",
    "Automatic" : "Automātisks",
    "Actions" : "Darbības",
    "Enable birthday calendar" : "Iespējot dzimšanas dienas kalendāru",
    "Show week numbers" : "Rādīt nedēļu numurus",
    "Settings & import" : "Iestatījumi un imports",
    "Notification" : "Paziņojums",
    "Email" : "E-pasts",
    "Busy" : "Aizņemts",
    "Unknown" : "Nezināms",
    "All day" : "Visas dienas",
    "Repeat" : "Atkārtot",
    "Save" : "Saglabāt",
    "never" : "nekad",
    "after" : "pēc",
    "Monday" : "Pirmdiena",
    "More" : "Vairāk",
    "Update" : "Atjaunināt",
    "Global" : "Globāls",
    "Personal" : "Personīgs",
    "Create a new event" : "Izveidot jaunu notikumu",
    "Details" : "Detaļas",
    "Attendees" : "Apmeklētāji",
    "Close" : "Aizvērt",
    "Anniversary" : "Gadadiena",
    "Week {number} of {year}" : "{number} nedēļa no {year}",
    "Daily" : "Katru dienu",
    "Weekly" : "Katru nedēļu",
    "When shared show full event" : "Ja koplietots, tad rādīt pilnu notikumu",
    "When shared show only busy" : "Ja koplietots, tad rādīt tikai aizņemts",
    "When shared hide this event" : "Ja koplietots, tad paslēpt notikumu",
    "Location" : "Vieta",
    "Description" : "Apraksts",
    "Status" : "Status",
    "Confirmed" : "Apstiprināts",
    "Tentative" : "Mēģinājums",
    "Categories" : "Kategorijas",
    "Presentation" : "Prezentācija",
    "Mail" : "E-pasts"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
